@@ -8,7 +8,7 @@ except ImportError:
     from io import StringIO
 
 
-__version__ = '0.2.3'
+__version__ = '0.2.4'
 
 
 def format_code(source,
@@ -32,6 +32,7 @@ def format_code(source,
         token_string = token[1]
         start_row, start_column = token[2]
         end_row, end_column = token[3]
+        line = token[4]
 
         # Preserve escaped newlines
         if (not previous_line.lstrip().startswith('#') and
@@ -45,7 +46,7 @@ def format_code(source,
         if start_row > last_row:
             last_column = 0
         if start_column > last_column:
-            formatted += ' ' * (start_column - last_column)
+            formatted += line[last_column:start_column]
 
         if (token_type == tokenize.STRING and
                 starts_with_triple(token_string) and
@@ -61,7 +62,7 @@ def format_code(source,
 
         previous_token_string = token_string
         previous_token_type = token_type
-        previous_line = token[4]
+        previous_line = line
 
         last_row = end_row
         last_column = end_column
@@ -106,9 +107,9 @@ def format_docstring(indentation, docstring,
         # Compensate for triple quotes by temporarily prepending 3 spaces.
         # This temporary prepending is undone below.
         if pre_summary_newline:
-            summary = indentation + summary
+            initial_indent = indentation
         else:
-            summary = indentation + 3 * ' ' + summary
+            initial_indent = 3 * ' ' + indentation
 
         return '''\
 """{pre_summary}{summary}
@@ -118,16 +119,17 @@ def format_docstring(indentation, docstring,
 '''.format(pre_summary=('\n' + indentation if pre_summary_newline else ''),
            summary=wrap_summary(normalize_summary(summary),
                                 wrap_length=summary_wrap_length,
-                                indentation=indentation).lstrip(),
+                                initial_indent=initial_indent,
+                                subsequent_indent=indentation).lstrip(),
            description='\n'.join([indent_non_indented(l, indentation).rstrip()
                                   for l in description.splitlines()]),
            post_description=('\n' if post_description_blank else ''),
            indentation=indentation)
     else:
-        return wrap_summary(indentation +
-                            '"""' + normalize_summary(contents) + '"""',
+        return wrap_summary('"""' + normalize_summary(contents) + '"""',
                             wrap_length=summary_wrap_length,
-                            indentation=indentation).strip()
+                            initial_indent=indentation,
+                            subsequent_indent=indentation).strip()
 
 
 def indent_non_indented(line, indentation):
@@ -182,14 +184,15 @@ def normalize_summary(summary):
     return summary
 
 
-def wrap_summary(summary, indentation, wrap_length):
+def wrap_summary(summary, initial_indent, subsequent_indent, wrap_length):
     """Return line-wrapped summary text."""
     if wrap_length > 0:
         import textwrap
         return '\n'.join(
             textwrap.wrap(summary,
                           width=wrap_length,
-                          subsequent_indent=indentation)).strip()
+                          initial_indent=initial_indent,
+                          subsequent_indent=subsequent_indent)).strip()
     else:
         return summary
 
